Class: Ecko::Plugins::Sponsor::Engine
- Inherits:
-
Object
- Object
- Ecko::Plugins::Sponsor::Engine
- Defined in:
- lib/ecko/plugins/sponsor/engine.rb
Class Method Summary collapse
-
.configure(schema) ⇒ Object
THis is the main engine configurer that the registry uses.
-
.gateways ⇒ Object
The gateways to be able to sponsor.
-
.process(package_id, account) ⇒ Object
Processes the donation here.
Class Method Details
.configure(schema) ⇒ Object
THis is the main engine configurer that the registry uses. THe schema is passed here and configured accordingly.
17 18 19 |
# File 'lib/ecko/plugins/sponsor/engine.rb', line 17 def configure(schema) Ecko::Plugins::Sponsor::Configurations.instance.setup(schema) end |
.gateways ⇒ Object
The gateways to be able to sponsor.
22 23 24 |
# File 'lib/ecko/plugins/sponsor/engine.rb', line 22 def gateways Ecko::Plugins::Sponsor::Configurations.instance.gateways end |